@@ -19,7 +19,7 @@ _internal_base_discovery_api = os.environ.get('INTERNAL_BASE_DISCOVERY_API',"htt
 _external_api_minio = os.environ.get('external_api_minio',"")
 _internal_api_minio = os.environ.get('internal_api_minio',"")
 
-_base_minio_url=os.environ.get('base_minio_url')
+_base_minio_url = os.environ.get('base_minio_url', "api.minio.data.storemesh.com")
 bucket_name = os.environ.get('bucketname', 'dataplatform')
 
 class Base:
