@@ -2,7 +2,7 @@ from tkinter.messagebox import NO
 from .base import Base
 
 from clickhouse_driver import Client
-from .utils.clickhouse import create_table, insert_ddf, insert_df
+from .utils.clickhouse import create_table, insert_ddf, insert_df, drop_table
 import pandas as pd
 import dask.dataframe as dd
 
@@ -71,4 +71,9 @@ class ClickHouse:
     def read(self, sqlQuery=None):
         if sqlQuery is None:
             raise Exception(f"plese input `sqlQuery` str but got {type(sqlQuery)}")
-        return self._client.query_dataframe(sqlQuery)
\ No newline at end of file
+        return self._client.query_dataframe(sqlQuery)
+    
+    def dropTable(self, tableName=None):
+        if tableName is None:
+            raise Exception(f"plese input `tableName` str but got {type(tableName)}")
+        return drop_table(client=self._client, table_name=tableName)
\ No newline at end of file
